@@ -1,6 +1,7 @@
 package App::Netdisco::Configuration;
 
 use App::Netdisco::Environment;
+use App::Netdisco::Util::SNMP ();
 use Dancer ':script';
 
 use Path::Class 'dir';
@@ -49,6 +50,19 @@ if (ref {} eq ref setting('database')) {
     }
 }
 
+# always set this
+$ENV{DBIC_TRACE_PROFILE} = 'console';
+
+# if snmp_auth or device_auth not set, add defaults to community{_rw}
+if ((setting('snmp_auth') and 0 == scalar @{ setting('snmp_auth') })
+    or (setting('device_auth') and 0 == scalar @{ setting('device_auth') })) {
+  config->{'community'} = [ @{setting('community')}, 'public' ];
+  config->{'community_rw'} = [ @{setting('community_rw')}, 'private' ];
+}
+
+# fix up device_auth (or create it from old snmp_auth and community settings)
+config->{'device_auth'} = [ App::Netdisco::Util::SNMP::fixup_device_auth() ];
+
 # defaults for workers
 setting('workers')->{queue} ||= 'PostgreSQL';
 if (exists setting('workers')->{interactives}
@@ -66,6 +80,27 @@ if (exists setting('workers')->{interactives}
 setting('dns')->{hosts_file} ||= '/etc/hosts';
 setting('dns')->{no} ||= ['fe80::/64','169.254.0.0/16'];
 
+# set max outstanding requests for AnyEvent::DNS
+$ENV{'PERL_ANYEVENT_MAX_OUTSTANDING_DNS'}
+  = setting('dns')->{max_outstanding} || 50;
+$ENV{'PERL_ANYEVENT_HOSTS'} = setting('dns')->{hosts_file};
+
+# load /etc/hosts
+setting('dns')->{'ETCHOSTS'} = {};
+{
+  # AE::DNS::EtcHosts only works for A/AAAA/SRV, but we want PTR.
+  # this loads+parses /etc/hosts file using AE. dirty hack.
+  use AnyEvent::Socket 'format_address';
+  use AnyEvent::DNS::EtcHosts;
+  AnyEvent::DNS::EtcHosts::_load_hosts_unless(sub{},AE::cv);
+  no AnyEvent::DNS::EtcHosts; # unimport
+
+  setting('dns')->{'ETCHOSTS'}->{$_} =
+    [ map { [ $_ ? (format_address $_->[0]) : '' ] }
+          @{ $AnyEvent::DNS::EtcHosts::HOSTS{ $_ } } ]
+    for keys %AnyEvent::DNS::EtcHosts::HOSTS;
+}
+
 # support unordered dictionary as if it were a single item list
 if (ref {} eq ref setting('device_identity')) {
   config->{'device_identity'} = [ setting('device_identity') ];
@@ -111,13 +146,4 @@ if (setting('reports') and ref {} eq ref setting('reports')) {
     }} keys %{ setting('reports') } ];
 }
 
-# set max outstanding requests for AnyEvent::DNS
-$ENV{'PERL_ANYEVENT_MAX_OUTSTANDING_DNS'}
-  = setting('dns')->{max_outstanding} || 50;
-$ENV{'PERL_ANYEVENT_HOSTS'}
-  = setting('dns')->{hosts_file} || '/etc/hosts';
-
-# always set this
-$ENV{DBIC_TRACE_PROFILE} = 'console';
-
 true;
