@@ -18,6 +18,7 @@ foreach my $report (@{setting('reports')}) {
     tag => $r,
     label => $report->{label},
     category => ($report->{category} || 'My Reports'),
+    ($report->{hidden} ? (hidden => true) : ()),
     provides_csv => true,
   });
 
@@ -25,15 +26,18 @@ foreach my $report (@{setting('reports')}) {
       # TODO: this should be done by creating a new Virtual Result class on
       # the fly (package...) and then calling DBIC register_class on it.
 
-      my $rs = schema('netdisco')->resultset('Virtual::GenericReport')->result_source;
-      $rs->view_definition($report->{query});
+      my $schema = ($report->{database} || 'netdisco');
+      my $rs = schema($schema)->resultset('Virtual::GenericReport')->result_source;
+      (my $query = $report->{query}) =~ s/;$//;
+
+      $rs->view_definition($query);
       $rs->remove_columns($rs->columns);
       $rs->add_columns( exists $report->{query_columns}
         ? @{ $report->{query_columns} }
         : (map {keys %{$_}} @{$report->{columns}})
       );
 
-      my $set = schema('netdisco')->resultset('Virtual::GenericReport')
+      my $set = schema($schema)->resultset('Virtual::GenericReport')
         ->search(undef, {
           result_class => 'DBIx::Class::ResultClass::HashRefInflator',
           ( (exists $report->{bind_params})
@@ -55,6 +59,7 @@ foreach my $report (@{setting('reports')}) {
       if (request->is_ajax) {
           template 'ajax/report/generic_report.tt',
               { results => \@results,
+                is_custom_report => true,
                 headings => [map {values %{$_}} @{$report->{columns}}],
                 columns => [map {keys %{$_}} @{$report->{columns}}] },
               { layout => undef };
